## v1.1.0 (2024-07-31)

[GitHub release](https://github.com/MitchMedeiros/mypackage/tag/v1.0.0)

- Made the source code visibility public

## v1.0.1 (2024-07-31)

[GitHub release](https://github.com/MitchMedeiros/mypackage/tag/v1.0.0)

- Updated the README with a new logo and badges.
- Added a pray function and unit test for it.

## v1.0.0 (2024-07-31)

[GitHub release](https://github.com/MitchMedeiros/mypackage/tag/v1.0.0)

Initial Release
